==> jc-1.4.0.tar.gz: javax/imageio/spi/ImageInputStreamSpi.h <==
// public abstract class javax.imageio.spi.ImageInputStreamSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 1d9c407f6156027f javax_imageio_spi_ImageInputStreamSpi

// header file dependencies
// @dep_header javax_imageio_spi_IIOServiceProvider

#include "javax/imageio/spi/IIOServiceProvider.h"

#ifndef _JC_javax_imageio_spi_ImageInputStreamSpi_H_
#define _JC_javax_imageio_spi_ImageInputStreamSpi_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_imageio_stream_ImageInputStream$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs	_jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs	_jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$refs	_jc_javax_imageio_spi_ImageInputStreamSpi$refs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs	_jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$object	_jc_javax_imageio_spi_ImageInputStreamSpi$object;

typedef const struct _jc_javax_imageio_spi_ImageInputStreamSpi$vmethods	_jc_javax_imageio_spi_ImageInputStreamSpi$vmethods;
typedef const struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtable	_jc_javax_imageio_spi_ImageInputStreamSpi$vtable;
typedef const struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtype	_jc_javax_imageio_spi_ImageInputStreamSpi$vtype;

// Constructors
extern void _jc_javax_imageio_spi_ImageInputStreamSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *);
extern void _jc_javax_imageio_spi_ImageInputStreamSpi$method$_init$99693247212c4336(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern jboolean _jc_javax_imageio_spi_ImageInputStreamSpi$method$canUseCacheFile$86e50483d06c0326(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *);
extern struct _jc_object *_jc_javax_imageio_spi_ImageInputStreamSpi$method$createInputStreamInstance$91aaad1c9b682a1f(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_javax_imageio_spi_ImageInputStreamSpi$method$createInputStreamInstance$db05cffc985ee097(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_imageio_spi_ImageInputStreamSpi$method$getInputClass$29e6fb8c04ae2248(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *);
extern jboolean _jc_javax_imageio_spi_ImageInputStreamSpi$method$needsCacheFile$eb3e6b64e84aa38c(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$canUseCacheFile$86e50483d06c0326;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$createInputStreamInstance$91aaad1c9b682a1f;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$createInputStreamInstance$db05cffc985ee097;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$getInputClass$29e6fb8c04ae2248;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$needsCacheFile$eb3e6b64e84aa38c;

// Virtual methods structure
struct _jc_javax_imageio_spi_ImageInputStreamSpi$vmethods {
	jboolean	(*canUseCacheFile$86e50483d06c0326)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *);
	struct _jc_object	*(*createInputStreamInstance$91aaad1c9b682a1f)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*createInputStreamInstance$db05cffc985ee097)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *);
	struct _jc_java_lang_Class$object	*(*getInputClass$29e6fb8c04ae2248)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *);
	jboolean	(*needsCacheFile$eb3e6b64e84aa38c)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *);
};

// Vtable
struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageInputStreamSpi$vmethods	javax_imageio_spi_ImageInputStreamSpi;
};

// Vtype
struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_ImageInputStreamSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs {
	struct _jc_java_lang_Class$object	*inputClass;
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$refs {
    _jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs	javax_imageio_spi_ImageInputStreamSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs	javax_imageio_spi_ImageInputStreamSpi;
};

// Object instance structure
struct _jc_javax_imageio_spi_ImageInputStreamSpi$object {
	_jc_javax_imageio_spi_ImageInputStreamSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_ImageInputStreamSpi$vtype	*vtype;
	_jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_ImageInputStreamSpi$vtype _jc_javax_imageio_spi_ImageInputStreamSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_ImageInputStreamSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_ImageInputStreamSpi$class_object;

#endif	/* _JC_javax_imageio_spi_ImageInputStreamSpi_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/spi/ImageInputStreamSpi.h <==
// public abstract class javax.imageio.spi.ImageInputStreamSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 1d9c407f6156027f javax_imageio_spi_ImageInputStreamSpi

// header file dependencies
// @dep_header javax_imageio_spi_IIOServiceProvider

#include "javax/imageio/spi/IIOServiceProvider.h"

#ifndef _JC_javax_imageio_spi_ImageInputStreamSpi_H_
#define _JC_javax_imageio_spi_ImageInputStreamSpi_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_imageio_stream_ImageInputStream$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs	_jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs	_jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$refs	_jc_javax_imageio_spi_ImageInputStreamSpi$refs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs	_jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs;
typedef struct _jc_javax_imageio_spi_ImageInputStreamSpi$object	_jc_javax_imageio_spi_ImageInputStreamSpi$object;

typedef const struct _jc_javax_imageio_spi_ImageInputStreamSpi$vmethods	_jc_javax_imageio_spi_ImageInputStreamSpi$vmethods;
typedef const struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtable	_jc_javax_imageio_spi_ImageInputStreamSpi$vtable;
typedef const struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtype	_jc_javax_imageio_spi_ImageInputStreamSpi$vtype;

// Constructors
extern void _jc_javax_imageio_spi_ImageInputStreamSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_spi_ImageInputStreamSpi$method$_init$99693247212c4336(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_imageio_spi_ImageInputStreamSpi$method$canUseCacheFile$86e50483d06c0326(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_imageio_spi_ImageInputStreamSpi$method$createInputStreamInstance$91aaad1c9b682a1f(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_imageio_spi_ImageInputStreamSpi$method$createInputStreamInstance$db05cffc985ee097(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_imageio_spi_ImageInputStreamSpi$method$getInputClass$29e6fb8c04ae2248(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_spi_ImageInputStreamSpi$method$needsCacheFile$eb3e6b64e84aa38c(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$canUseCacheFile$86e50483d06c0326;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$createInputStreamInstance$91aaad1c9b682a1f;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$createInputStreamInstance$db05cffc985ee097;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$getInputClass$29e6fb8c04ae2248;
extern _jc_method _jc_javax_imageio_spi_ImageInputStreamSpi$method_info$needsCacheFile$eb3e6b64e84aa38c;

// Virtual methods structure
struct _jc_javax_imageio_spi_ImageInputStreamSpi$vmethods {
	jboolean	(*canUseCacheFile$86e50483d06c0326)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createInputStreamInstance$91aaad1c9b682a1f)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createInputStreamInstance$db05cffc985ee097)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getInputClass$29e6fb8c04ae2248)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *) _JC_JCNI_ATTR;
	jboolean	(*needsCacheFile$eb3e6b64e84aa38c)(_jc_env *, struct _jc_javax_imageio_spi_ImageInputStreamSpi$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageInputStreamSpi$vmethods	javax_imageio_spi_ImageInputStreamSpi;
};

// Vtype
struct _jc_javax_imageio_spi_ImageInputStreamSpi$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_ImageInputStreamSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs {
	struct _jc_java_lang_Class$object	*inputClass;
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$refs {
    _jc_javax_imageio_spi_ImageInputStreamSpi$sub_refs	javax_imageio_spi_ImageInputStreamSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageInputStreamSpi$sub_nonrefs	javax_imageio_spi_ImageInputStreamSpi;
};

// Object instance structure
struct _jc_javax_imageio_spi_ImageInputStreamSpi$object {
	_jc_javax_imageio_spi_ImageInputStreamSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_ImageInputStreamSpi$vtype	*vtype;
	_jc_javax_imageio_spi_ImageInputStreamSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_ImageInputStreamSpi$vtype _jc_javax_imageio_spi_ImageInputStreamSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_ImageInputStreamSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_ImageInputStreamSpi$class_object;

#endif	/* _JC_javax_imageio_spi_ImageInputStreamSpi_H_ */
